/***************************************************************************
 * readenv.c: code to read settings from the evironment for e2tools.
 * By Terry R. McConnell
 *
 * Adapted from ldisk.c:
 * Copyright (C) 1995 Claus Tondering, ct@login.dknet.dk
 * This file may be redistributed under the terms of the GNU Public License.
 ***************************************************************************/
 
#include <limits.h>
#include <stdlib.h>
#include <string.h>

#include "e2err.h"
#include "env.h"
#include "ext2_fs.h"

char device[PATH_MAX];
char e2cwd[NAME_MAX];

/* It would probably be better to set this to the inode of the working
   directory in readenv using ext2fs_lookup, but we have chosen not to
   do so. */
ino_t cwdino = EXT2_ROOT_INO;


/****************************************************************************
 * readenv(): Determine the device name and starting directory from the 
 * environment.
 *
 * Returns an error code
 ****************************************************************************/

int
readenv()
{
	int err;
	char env[PATH_MAX+NAME_MAX+2];
	char *envp, *ptr;

	/* Decode E2CWD environment */
	envp=getenv("E2CWD");
	
	if (!envp)
		return E2E_NOCWD;

	strcpy(env,envp);   /* We are going to modify it, so we make a copy */

	ptr=strchr(env,':');

	if ((!ptr) || (strlen(ptr)>NAME_MAX+1))
		return E2E_BADCWD;

	*ptr = 0;
	strcpy(e2cwd,ptr+1);
	strcpy(device,env);
	return 0;
}
